@@ -24,7 +24,7 @@
 #define WITH_SIMD
 #define WITH_AVX2
 #define WITH_CUPS
-/* #undef WITH_JPEG */
+#define WITH_JPEG
 /* #undef WITH_WIN8 */
 /* #undef WITH_AAD */
 /* #undef WITH_CAIRO */
@@ -35,7 +35,7 @@
 /* #undef WITH_MACAUDIO */
 /* #undef WITH_OSS */
 #define WITH_ALSA
-/* #undef WITH_PULSE */
+#define WITH_PULSE
 /* #undef WITH_IOSAUDIO */
 /* #undef WITH_OPENSLES */
 /* #undef WITH_GSM */
@@ -62,7 +62,7 @@
 
 #define WITH_CHANNELS
 #define WITH_CLIENT_CHANNELS
-/* #undef WITH_SERVER_CHANNELS */
+#define WITH_SERVER_CHANNELS
 
 /* #undef WITH_CHANNEL_GFXREDIR */
 /* #undef WITH_CHANNEL_RDPAPPLIST */
@@ -178,8 +178,8 @@
 /* #undef CHANNEL_TSMF */
 /* #undef CHANNEL_TSMF_CLIENT */
 /* #undef CHANNEL_TSMF_SERVER */
-/* #undef CHANNEL_URBDRC */
-/* #undef CHANNEL_URBDRC_CLIENT */
+#define CHANNEL_URBDRC
+#define CHANNEL_URBDRC_CLIENT
 /* #undef CHANNEL_URBDRC_SERVER */
 #define CHANNEL_VIDEO
 #define CHANNEL_VIDEO_CLIENT
@@ -218,7 +218,7 @@
 /* #undef WITH_DEBUG_RINGBUFFER */
 
 /* Proxy */
-/* #undef WITH_PROXY_MODULES */
+#define WITH_PROXY_MODULES
 /* #undef WITH_PROXY_EMULATE_SMARTCARD */
 
 /** If defined linux/vm_sockets.h support is available.
@@ -227,4 +227,10 @@
  */
 #define HAVE_AF_VSOCK_H
 
+/** If library is build without these do permanently hide symbols
+ *
+ * \since version 3.17.2
+ */
+/* #undef WITHOUT_FREERDP_3x_DEPRECATED */
+
 #endif /* FREERDP_CONFIG_H */
