@@ -2,8 +2,8 @@
 #define WINPR_BUILD_FLAGS_H
 
 #define WINPR_CFLAGS "-march=arrowlake -O2 -pipe -fvisibility=hidden -fno-omit-frame-pointer -Wredundant-decls -Wimplicit-function-declaration -fvisibility=hidden "
-#define WINPR_COMPILER_ID "Clang"
-#define WINPR_COMPILER_VERSION "21.1.0"
+#define WINPR_COMPILER_ID "GNU"
+#define WINPR_COMPILER_VERSION "15.2.0"
 #define WINPR_TARGET_ARCH "x64"
 #define WINPR_BUILD_CONFIG ""
 #define WINPR_BUILD_TYPE "RelWithDebInfo"
